# Unpacker
[![PyPI version](https://badge.fury.io/py/unpacker.svg)](https://badge.fury.io/py/unpacker)
![Python version](https://img.shields.io/badge/python-3.10+-brightgreen)
![Operating system](https://img.shields.io/badge/os-linux%20%7c%20macOS-brightgreen)
![Coverage](https://img.shields.io/badge/coverage-100%25-brightgreen)

Clean up and unpack items in working directory

## Usage
Run
```shell
unpack
```

## Installation
```shell
pip install unpacker
```
